@@ -21,11 +21,14 @@
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
 
+#include "config.h"
+
 #include <glade/glade.h>
+#include <string.h>
 #include "zenity.h"
 #include "util.h"
 
-ZenityData	*zen_data;
+static ZenityData	*zen_data;
 
 static void zenity_fileselection_dialog_response (GtkWidget *widget, int response, gpointer data);
 
@@ -54,6 +57,9 @@ void zenity_fileselection (ZenityData *data, ZenityFileData *file_data)
 					GTK_STOCK_OK, GTK_RESPONSE_OK,
 					NULL);
 
+  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), 
+                                                  file_data->confirm_overwrite);
+
   g_signal_connect (G_OBJECT (dialog), "response", 
                     G_CALLBACK (zenity_fileselection_dialog_response), file_data);
 
@@ -80,6 +86,11 @@ void zenity_fileselection (ZenityData *data, ZenityFileData *file_data)
     gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (dialog), TRUE);
 
   zenity_util_show_dialog (dialog);
+
+  if(data->timeout_delay > 0) {
+    g_timeout_add (data->timeout_delay * 1000, (GSourceFunc) zenity_util_timeout_handle, NULL);
+  }
+
   gtk_main ();
 }
 
@@ -88,7 +99,6 @@ zenity_fileselection_dialog_response (GtkWidget *widget, int response, gpointer
 {
   ZenityFileData *file_data = data;
   GSList *selections, *iter;
-  int i;
 	  
   switch (response) {
     case GTK_RESPONSE_OK:
